==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d3/d10/string__func_8h.js <==
var string__func_8h =
[
    [ "IsPrintable", "d3/d10/string__func_8h.html#a95f235339178d29af26af2b493127477", null ],
    [ "IsTextDirectionChar", "d3/d10/string__func_8h.html#abe0466638350fcf884bcce06afbbdb60", null ],
    [ "IsUtf8Part", "d3/d10/string__func_8h.html#a121a85c53431b7a0359bb13b942ba522", null ],
    [ "IsValidChar", "d3/d10/string__func_8h.html#a6f0d67a8e92992edf769b92b540fa087", null ],
    [ "IsWhitespace", "d3/d10/string__func_8h.html#af15a75bd2eb21ce1bdf0f4bb61dcc288", null ],
    [ "md5sumToString", "d3/d10/string__func_8h.html#a5c07a740ab5aedbddd024854d7737eb7", null ],
    [ "seprintf", "d3/d10/string__func_8h.html#a178e95747b087f89b97b811375c67cfb", null ],
    [ "str_fix_scc_encoded", "d3/d10/string__func_8h.html#af045543890df1473906e485783e427c0", null ],
    [ "str_fmt", "d3/d10/string__func_8h.html#a457022a870b9fab247c07d0cfc47e6f2", null ],
    [ "str_strip_colours", "d3/d10/string__func_8h.html#a3fcdc67f9b55f19893a47491431bf62f", null ],
    [ "str_validate", "d3/d10/string__func_8h.html#ac083e48742e90af4957a2fa6d68ceb04", null ],
    [ "strecat", "d3/d10/string__func_8h.html#a3f700f64aabcf022e93c7840d91ef3ad", null ],
    [ "strecpy", "d3/d10/string__func_8h.html#ad0e02ee8042de666ac125f0bcb455c95", null ],
    [ "stredup", "d3/d10/string__func_8h.html#a56eee2f95096b6dce1736e7640d8efa4", null ],
    [ "StrEmpty", "d3/d10/string__func_8h.html#a924368b99577eb375f3f8a63cab37f9a", null ],
    [ "strnatcmp", "d3/d10/string__func_8h.html#a3fa4ca9933b58866a111c103703dcc2e", null ],
    [ "strtolower", "d3/d10/string__func_8h.html#ab21b40856002bb23a819f657220b8898", null ],
    [ "StrValid", "d3/d10/string__func_8h.html#aac21f5e1ef3380f0a9ef59c577a702f2", null ],
    [ "ttd_strnlen", "d3/d10/string__func_8h.html#ab9aa9299931859f3326b2d65d029f3d3", null ],
    [ "Utf16DecodeChar", "d3/d10/string__func_8h.html#a8838ca3d7d8fd90eb04bd26cde73a6f4", null ],
    [ "Utf16DecodeSurrogate", "d3/d10/string__func_8h.html#a258939900cae411f02100ae188fc7210", null ],
    [ "Utf16IsLeadSurrogate", "d3/d10/string__func_8h.html#a4d0bdc9184c2abece3876d0a44ab514f", null ],
    [ "Utf16IsTrailSurrogate", "d3/d10/string__func_8h.html#a33053e92a28150b2c0346fdd92da0063", null ],
    [ "Utf8CharLen", "d3/d10/string__func_8h.html#a90b1b6882fcf595ea97842ea7e38e7d6", null ],
    [ "Utf8Consume", "d3/d10/string__func_8h.html#af61f02404911458b9dc7aa94a59d9eee", null ],
    [ "Utf8Decode", "d3/d10/string__func_8h.html#adb406c375fc972a86860b1ac67514d1e", null ],
    [ "Utf8Encode", "d3/d10/string__func_8h.html#aaf287a91a7e9de9d174d9c15d9052467", null ],
    [ "Utf8EncodedCharLen", "d3/d10/string__func_8h.html#abca0980443b6c6636ca3ba6d1d09edbd", null ],
    [ "Utf8PrevChar", "d3/d10/string__func_8h.html#ad33b4e601fb0d66257af09400da9f78d", null ],
    [ "Utf8PrevChar", "d3/d10/string__func_8h.html#a1424fc3aa46020edb449d77ca2202154", null ],
    [ "Utf8StringLength", "d3/d10/string__func_8h.html#a7a6f406f6ee59a791f12dc723b81c828", null ],
    [ "Utf8TrimString", "d3/d10/string__func_8h.html#ac4ddf5bb187cb1c07c76833256471272", null ],
    [ "ValidateString", "d3/d10/string__func_8h.html#af7b2208b79a70916d206b3db34df2a99", null ],
    [ "vseprintf", "d3/d10/string__func_8h.html#ac8768a86f0877956fdf0110ac2ed6e62", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d3/d10/string__func_8h.js <==
var string__func_8h =
[
    [ "IsPrintable", "d3/d10/string__func_8h.html#a95f235339178d29af26af2b493127477", null ],
    [ "IsTextDirectionChar", "d3/d10/string__func_8h.html#abe0466638350fcf884bcce06afbbdb60", null ],
    [ "IsUtf8Part", "d3/d10/string__func_8h.html#a121a85c53431b7a0359bb13b942ba522", null ],
    [ "IsValidChar", "d3/d10/string__func_8h.html#a6f0d67a8e92992edf769b92b540fa087", null ],
    [ "IsWhitespace", "d3/d10/string__func_8h.html#af15a75bd2eb21ce1bdf0f4bb61dcc288", null ],
    [ "md5sumToString", "d3/d10/string__func_8h.html#a5c07a740ab5aedbddd024854d7737eb7", null ],
    [ "seprintf", "d3/d10/string__func_8h.html#a178e95747b087f89b97b811375c67cfb", null ],
    [ "str_fix_scc_encoded", "d3/d10/string__func_8h.html#af045543890df1473906e485783e427c0", null ],
    [ "str_fmt", "d3/d10/string__func_8h.html#a8f675d91503a690e53ddb33334f1494d", null ],
    [ "str_strip_colours", "d3/d10/string__func_8h.html#a3fcdc67f9b55f19893a47491431bf62f", null ],
    [ "str_validate", "d3/d10/string__func_8h.html#a68e245d6a9a20cde982b290b9a4b8574", null ],
    [ "str_validate", "d3/d10/string__func_8h.html#a73e50a6106e19193a8b02ca72bdb00de", null ],
    [ "strecat", "d3/d10/string__func_8h.html#a3f700f64aabcf022e93c7840d91ef3ad", null ],
    [ "strecpy", "d3/d10/string__func_8h.html#ad0e02ee8042de666ac125f0bcb455c95", null ],
    [ "stredup", "d3/d10/string__func_8h.html#af85b588c4e51957b10f61ad76c3ced2b", null ],
    [ "StrEmpty", "d3/d10/string__func_8h.html#a924368b99577eb375f3f8a63cab37f9a", null ],
    [ "strnatcmp", "d3/d10/string__func_8h.html#a3fa4ca9933b58866a111c103703dcc2e", null ],
    [ "strtolower", "d3/d10/string__func_8h.html#ab21b40856002bb23a819f657220b8898", null ],
    [ "strtolower", "d3/d10/string__func_8h.html#aef180f69fd8eee03b8d0c8c6cf9090f7", null ],
    [ "StrValid", "d3/d10/string__func_8h.html#aac21f5e1ef3380f0a9ef59c577a702f2", null ],
    [ "ttd_strnlen", "d3/d10/string__func_8h.html#ab9aa9299931859f3326b2d65d029f3d3", null ],
    [ "Utf16DecodeChar", "d3/d10/string__func_8h.html#a8838ca3d7d8fd90eb04bd26cde73a6f4", null ],
    [ "Utf16DecodeSurrogate", "d3/d10/string__func_8h.html#a258939900cae411f02100ae188fc7210", null ],
    [ "Utf16IsLeadSurrogate", "d3/d10/string__func_8h.html#a4d0bdc9184c2abece3876d0a44ab514f", null ],
    [ "Utf16IsTrailSurrogate", "d3/d10/string__func_8h.html#a33053e92a28150b2c0346fdd92da0063", null ],
    [ "Utf8CharLen", "d3/d10/string__func_8h.html#a90b1b6882fcf595ea97842ea7e38e7d6", null ],
    [ "Utf8Consume", "d3/d10/string__func_8h.html#af61f02404911458b9dc7aa94a59d9eee", null ],
    [ "Utf8Consume", "d3/d10/string__func_8h.html#a618fb89323feccd079d19c43ee0351e1", null ],
    [ "Utf8Decode", "d3/d10/string__func_8h.html#adb406c375fc972a86860b1ac67514d1e", null ],
    [ "Utf8Encode", "d3/d10/string__func_8h.html#aaf287a91a7e9de9d174d9c15d9052467", null ],
    [ "Utf8Encode", "d3/d10/string__func_8h.html#a98fa8df7080360b425274e85965a2a51", null ],
    [ "Utf8EncodedCharLen", "d3/d10/string__func_8h.html#abca0980443b6c6636ca3ba6d1d09edbd", null ],
    [ "Utf8PrevChar", "d3/d10/string__func_8h.html#ad33b4e601fb0d66257af09400da9f78d", null ],
    [ "Utf8PrevChar", "d3/d10/string__func_8h.html#a1424fc3aa46020edb449d77ca2202154", null ],
    [ "Utf8StringLength", "d3/d10/string__func_8h.html#a7a6f406f6ee59a791f12dc723b81c828", null ],
    [ "Utf8TrimString", "d3/d10/string__func_8h.html#ac4ddf5bb187cb1c07c76833256471272", null ],
    [ "ValidateString", "d3/d10/string__func_8h.html#af7b2208b79a70916d206b3db34df2a99", null ],
    [ "vseprintf", "d3/d10/string__func_8h.html#a694fb8e1bd95a854d754235be0b93512", null ]
];
